/*
 * SPDX-FileCopyrightText: syuilo and misskey-project
 * SPDX-License-Identifier: AGPL-3.0-only
 */

import { Inject, Injectable } from '@nestjs/common';
import { Endpoint } from '@/server/api/endpoint-base.js';
import { QueueService } from '@/core/QueueService.js';
import { ModerationLogService } from '@/core/ModerationLogService.js';
import type { DriveFilesRepository } from '@/models/_.js';
import { DI } from '@/di-symbols.js';

export const meta = {
	secure: true,
	requireCredential: true,
	requiredRolePolicy: 'canManageCustomEmojis',
} as const;

export const paramDef = {
	type: 'object',
	properties: {
		fileId: { type: 'string', format: 'misskey:id' },
	},
	required: ['fileId'],
} as const;

@Injectable()
export default class extends Endpoint<typeof meta, typeof paramDef> { // eslint-disable-line import/no-default-export
	constructor(
		private queueService: QueueService,
		private readonly moderationLogService: ModerationLogService,
		@Inject(DI.driveFilesRepository)
		private readonly driveFilesRepository: DriveFilesRepository,
	) {
		super(meta, paramDef, async (ps, me) => {
			const file = await driveFilesRepository.findOneByOrFail({ id: ps.fileId });
			await this.moderationLogService.log(me, 'importCustomEmojis', {
				fileName: file.name,
			});
			await this.queueService.createImportCustomEmojisJob(me, ps.fileId);
		});
	}
}
